@@ -566,8 +566,8 @@ class Tableview(ttk.Frame):
     def tablecolumns_visible(self):
         """A list of visible table column objects"""
         cids = list(self.view.cget("displaycolumns"))
-        if "all" in cids:
-            return self.tablecolumns
+        if "#all" in cids:
+            return self._tablecols
         columns = []
         for cid in cids:
             # the cidmap expects an integer
@@ -688,7 +688,7 @@ class Tableview(ttk.Frame):
         if self._stripecolor is not None:
             self.apply_table_stripes(self._stripecolor)
 
-        self._select_first_visible_item()
+        self.goto_first_page()
 
     def insert_row(self, index=END, values=[]) -> TableRow:
         """Insert a row into the tableview at index.
@@ -895,6 +895,9 @@ class Tableview(ttk.Frame):
             self._iidmap.clear()
             records = self.view.get_children("")
             self.view.delete(*records)
+        # route to new page if no records visible
+        if len(self._viewdata) == 0:
+            self.goto_page()        
 
     def insert_column(
         self,
@@ -1036,8 +1039,13 @@ class Tableview(ttk.Frame):
             self.reset_table()
 
         self.unload_table_data()
-        page_start = self._rowindex.get()
-        page_end = self._rowindex.get() + self._pagesize.get()
+
+        if self._paginated:
+            page_start = self._rowindex.get()
+            page_end = self._rowindex.get() + self._pagesize.get()
+        else:
+            page_start = 0
+            page_end = len(self._tablerows)
 
         if self._filtered:
             rowdata = self._tablerows_filtered[page_start:page_end]
@@ -1225,7 +1233,14 @@ class Tableview(ttk.Frame):
 
     def _select_first_visible_item(self):
         try:
-            self.view.selection_set(self.tablerows_visible[0].iid)
+            iid = self.tablerows_visible[0].iid
+            self.view.selection_set(iid)
+            # must force focus, sometimes just focus on iid doesn't work
+            self.view.focus_force()
+            # this sets the focus on the specific row item
+            self.view.focus(iid)
+            # make sure the row is visible
+            self.view.see(iid)
         except:
             pass
 
@@ -1265,12 +1280,13 @@ class Tableview(ttk.Frame):
         pagelimit = self._pagelimit.get()
         pageindex = self._pageindex.get()
         if pageindex > pagelimit:
-            pageindex = pagelimit - 1
+            pageindex = pagelimit
             self._pageindex.set(pageindex)
         elif pageindex < 0:
-            pageindex = 0
+            pageindex = 1
             self._pageindex.set(pageindex)
-        self._rowindex.set(pageindex * self.pagesize)
+        rowindex = (pageindex * self.pagesize) - self.pagesize
+        self._rowindex.set(rowindex)
         self.load_table_data()
         self._select_first_visible_item()
 
@@ -1320,12 +1336,15 @@ class Tableview(ttk.Frame):
 
         try:
             sortedrows = sorted(
-                tablerows, reverse=columnsort, key=lambda x: x._values[index]
+                tablerows, reverse=columnsort, key=lambda x: x.values[index]
             )
-        except IndexError:
+        except:
+            # when data is missing, or sometimes with numbers
+            # this is still not right, but it works most of the time
+            # fix sometime down the road when I have time 
             self.fill_empty_columns()
             sortedrows = sorted(
-                tablerows, reverse=columnsort, key=lambda x: x._values[index]
+                tablerows, reverse=columnsort, key=lambda x: int(x.values[index])
             )
         if self.is_filtered:
             self._tablerows_filtered = sortedrows
@@ -1338,6 +1357,7 @@ class Tableview(ttk.Frame):
 
         self.unload_table_data()
         self.load_table_data()
+        self._select_first_visible_item()
 
     # DATA SEARCH & FILTERING
 
@@ -1378,8 +1398,8 @@ class Tableview(ttk.Frame):
         self.reset_column_filters()
         self.reset_column_sort()
 
-        self.load_table_data()
         self._column_sort_header_reset()
+        self.goto_first_page() # needed?
 
     def filter_column_to_value(self, event=None, cid=None, value=None):
         """Hide all records except for records where the current
@@ -1442,6 +1462,8 @@ class Tableview(ttk.Frame):
     def hide_selected_rows(self):
         """Hide the currently selected rows"""
         selected = self.view.selection()
+        view_cnt = len(self._viewdata)
+        hide_cnt = len(selected)
         self.view.detach(*selected)
 
         tablerows = []
@@ -1457,7 +1479,17 @@ class Tableview(ttk.Frame):
             if self.is_filtered:
                 self.tablerows_filtered.remove(row)
 
-        self.load_table_data()
+        if hide_cnt == view_cnt:
+            # assuming that if the count of the records on the page are
+            #   selected for hiding, then need to go to the next page
+            # The call to `load_table_data` is duplicative, but currently
+            #   this is the only way to get this to work until I've 
+            #   refactored this bit.
+            self.load_table_data()
+            self.goto_page()
+        else:
+            self.load_table_data()
+        
 
     def hide_selected_column(self, event=None, cid=None):
         """Detach the selected column from the tableview. This method
@@ -1819,8 +1851,12 @@ class Tableview(ttk.Frame):
             kw = {}
             if bg is None:
                 kw["background"] = colors.active
+            else:
+                kw["background"] = bg
             if fg is None:
                 kw["foreground"] = colors.inputfg
+            else:
+                kw["foreground"] = fg
             self.view.tag_configure("striped", **kw)
 
     def autofit_columns(self):
@@ -2443,7 +2479,11 @@ class TableCellRightClickMenu(tk.Menu):
         """Delete the selected rows"""
         iids = self.view.selection()
         if len(iids) > 0:
+            # setting to prev should be in master?
+            prev_item = self.view.prev(iids[0])
             self.master.delete_rows(iids=iids)
+            self.view.focus(prev_item)
+            self.view.selection_set(prev_item)
 
 
 class TableHeaderRightClickMenu(tk.Menu):
